@@ -4,9 +4,9 @@
  * GChemPaint
  * bondtool.cc
  *
- * Copyright (C) 2001-2003
+ * Copyright (C) 2001-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -68,11 +68,6 @@ bool gcpBondTool::OnClicked()
 		{
 		case BondType:
 			pBond = (gcpBond*)m_pObject;
-			if ((pBond->GetType() == NormalBondType) && (pBond->GetOrder() < 3))
-			{//TODO: in the future, test maximum bond order for atoms to allow for quadruple bonds
-				if (!((gcpAtom*)pBond->GetAtom(0))->AcceptNewBonds()) return false;
-				if (!((gcpAtom*)pBond->GetAtom(1))->AcceptNewBonds()) return false;
-			}
 			m_pAtom = (gcpAtom*)pBond->GetAtom(0);
 			m_pAtom->GetCoords(&m_x0, &m_y0, NULL);
 			m_pAtom = (gcpAtom*)pBond->GetAtom(1);
@@ -261,6 +256,12 @@ void gcpBondTool::OnRelease()
 	if ((m_pObject) && (m_pObject->GetType() == BondType))
 	{
 		FinalizeBond();
+		gcpAtom* pAtom = (gcpAtom*) ((gcpBond*)m_pObject)->GetAtom(0);
+		pAtom->Update ();
+		m_pView->Update(pAtom);
+		pAtom = (gcpAtom*) ((gcpBond*)m_pObject)->GetAtom(1);
+		pAtom->Update ();
+		m_pView->Update(pAtom);
 		m_pOp->AddObject(m_pObject, 1);
 		pDoc->FinishOperation();
 		m_pOp = NULL;
@@ -303,11 +304,13 @@ void gcpBondTool::OnRelease()
 	}
 	if (m_pObject->GetType() == AtomType)
 	{
-		if (m_pAtom) pAtom = m_pAtom;
-		else
-		{
-			pAtom = new gcpAtom(CurZ, m_x1 / m_dZoomFactor, m_y1 / m_dZoomFactor, 0);
-			pDoc->AddAtom(pAtom);
+		if (m_pAtom) {
+			if (m_pObject == m_pAtom)
+				return;
+			pAtom = m_pAtom;
+		} else {
+			pAtom = new gcpAtom (CurZ, m_x1 / m_dZoomFactor, m_y1 / m_dZoomFactor, 0);
+			pDoc->AddAtom (pAtom);
 		}
 		pBond = (gcpBond*)pAtom->GetBond((gcpAtom*)m_pObject);
 		if (pBond)
@@ -318,6 +321,12 @@ void gcpBondTool::OnRelease()
 			m_pObject = pBond;
 			m_bChanged = true;
 			FinalizeBond(); 
+			gcpAtom* pAtom = (gcpAtom*) ((gcpBond*)m_pObject)->GetAtom(0);
+			pAtom->Update ();
+			m_pView->Update(pAtom);
+			pAtom = (gcpAtom*) ((gcpBond*)m_pObject)->GetAtom(1);
+			pAtom->Update ();
+			m_pView->Update(pAtom);
 			m_pView->Update(pBond);
 			m_pOp->AddObject(pBond, 1);
 			pDoc->FinishOperation();
@@ -385,8 +394,6 @@ void gcpBondTool::FinalizeBond()
 		m_pView->Update(pBond);
 	}
 	else ((gcpBond*)m_pObject)->SetOrder(BondOrder);
-	m_pView->Update(((gcpBond*)m_pObject)->GetAtom(0));
-	m_pView->Update(((gcpBond*)m_pObject)->GetAtom(1));
 }
 
 void gcpBondTool::SetType(gcpBond* pBond)
@@ -560,7 +567,6 @@ gcpSquiggleBondTool::~gcpSquiggleBondTool()
 
 void gcpSquiggleBondTool::Draw()
 {
-	while(gtk_events_pending()) gtk_main_iteration();
 	GnomeCanvasPathDef *path_def;
 	path_def = gnome_canvas_path_def_new();
 	gnome_canvas_path_def_moveto(path_def, m_x0, m_y0);
