@@ -4,9 +4,9 @@
  * GChemPaint
  * globals.h 
  *
- * Copyright (C) 2001-2003
+ * Copyright (C) 2001-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -35,7 +35,8 @@ enum
 	NewMenu,
 	OpenMenu,
 	SaveMenu,
-	SaveAsMenu
+	SaveAsMenu,
+	SaveAsImageMenu
 };
 enum
 {
@@ -64,3 +65,10 @@ enum
 //Text tools bar
 extern GtkWidget	*TextToolBar, *BoldBtn, *ItalicBtn, *UnderlineBtn, *StrikethroughBtn,
 									*SubscriptBtn, *SuperscriptBtn, *FontBtn;
+
+#ifdef GTK_IS_26
+#define SET_ICON(w) gtk_window_set_icon_name (GTK_WINDOW (w), "gchempaint")
+#else
+extern GdkPixbuf *icon;
+#define SET_ICON(w) gtk_window_set_icon (GTK_WINDOW (w), icon)
+#endif
